@@ -12,14 +12,15 @@ def manage(command, on_server=True):
 
 def migrate(params='', do_backup=True):
     if do_backup:
-        mysqldump('before-migrate/')
+        mysqldump('hosting/backups/before-migrate')
     manage('migrate --noinput %s' % params)
 
 def syncdb():
     manage('syncdb --noinput')
 
 def compress():
-    manage('synccompress')
+    with settings(warn_only=True):
+        manage('synccompress')
 
 def test():
     pass
